# Practical work 6 - Modular programs

**Akhmadullin Ramil,**
**KI22-16/1b,**
**Variant 5,**

`$ python package --help` - calling the interface to demonstrate the work

`$ pythonpackage -t` - calling test mode

example:

```python
from greedy_alg import greedy
print(greedy({'MTS': {4, 5, 7, 9}, 'MEGAFON': {1, 2, 3, 4, 5, 6}}, {1, 2, 3, 4, 5, 7}))
```


`['MEGAFON', 'MTS']`